@@ -131,7 +131,7 @@ class Shop(DeactivableMixin, ModelSQL, ModelView):
         pool = Pool()
         Company = pool.get('company.company')
         company_id = cls.default_company()
-        if company_id:
+        if company_id is not None and company_id >= 0:
             company = Company(company_id)
             return company.currency.id
 
